## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)
options(warn = -1)

library(ggtree)
library(ggtreeSpace)
library(phytools)
library(ggplot2)

## ----eval = FALSE-------------------------------------------------------------
#  if (!require("BiocManager")) {
#    install.packages("BiocManager")
#  }
#  BiocManager::install("ggtreeSpace")

## ----example0, echo=TRUE------------------------------------------------------
library(ggtree)
library(ggtreeSpace)
library(phytools)
library(ggplot2)

tr <- rtree(15)
td <- fastBM(tr, nsim = 2)
ggtreespace(tr, td) +
  geom_tippoint()

## ----example1, echo=TRUE------------------------------------------------------
tr1 <- rtree(15)
td1 <- fastBM(tr1, nsim = 2)
ggplot() +
  geom_treespace(tr1, td1)

## ----example2, echo=TRUE------------------------------------------------------
tr <- rtree(15)
td <- fastBM(tr, nsim = 2, bounds = c(0, Inf))
col <- colorRampPalette(c("#FFFFCC", "#FFEDA0", "#FED976", "#FEB24C", "#FD8D3C", "#FC4E2A", "#E31A1C", "#B10026"))(24)
tdex <- data.frame(
  z = fastBM(tr, nsim = 1, bounds = c(0, Inf)),
  node = 1:15
)
p <- ggtreespace(tr, td)
p %<+% tdex +
  geom_tippoint() +
  geom_tsheatmap(trait = "z", alpha = 0.7, resolution = 0.01, bin = 24) +
  scale_fill_manual(
    values = col,
    guide = guide_colorsteps(show.limits = TRUE)
  ) +
  theme_treespace2() +
  theme(
    legend.key.height = unit(1, "null"),
    legend.justification.top = "right"
  )

## ----echo=FALSE---------------------------------------------------------------
sessionInfo()

